@@ -1,4 +1,4 @@
-/*	$NetBSD: options.c,v 1.31 2001/02/26 13:06:43 wiz Exp $	*/
+/*	$NetBSD: options.c,v 1.29 1999/07/09 03:05:50 christos Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -41,7 +41,7 @@
 #if 0
 static char sccsid[] = "@(#)options.c	8.2 (Berkeley) 5/4/95";
 #else
-__RCSID("$NetBSD: options.c,v 1.31 2001/02/26 13:06:43 wiz Exp $");
+__RCSID("$NetBSD: options.c,v 1.29 1999/07/09 03:05:50 christos Exp $");
 #endif
 #endif /* not lint */
 
@@ -70,7 +70,7 @@ __RCSID("$NetBSD: options.c,v 1.31 2001/02/26 13:06:43 wiz Exp $");
 char *arg0;			/* value of $0 */
 struct shparam shellparam;	/* current positional parameters */
 char **argptr;			/* argument list for builtin commands */
-char *optionarg;		/* set by nextopt (like getopt) */
+char *optarg;			/* set by nextopt (like getopt) */
 char *optptr;			/* used by nextopt */
 
 char *minusc;			/* argument to -c option */
@@ -110,10 +110,8 @@ procargs(argc, argv)
 			optlist[i].val = 0;
 	arg0 = argv[0];
 	if (sflag == 0 && minusc == NULL) {
-		commandname = argv[0];
-		arg0 = *argptr++;
-		setinputfile(arg0, 0);
-		commandname = arg0;
+		commandname = arg0 = *argptr++;
+		setinputfile(commandname, 0);
 	}
 	/* POSIX 1003.2: first arg after -c cmd is $0, remainder $1... */
 	if (argptr && minusc && *argptr)
@@ -537,7 +535,7 @@ nextopt(optstring)
 	if (*++q == ':') {
 		if (*p == '\0' && (p = *argptr++) == NULL)
 			error("No arg for -%c option", c);
-		optionarg = p;
+		optarg = p;
 		p = NULL;
 	}
 	optptr = p;
